==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/TransientValueReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.TransientValueReference;
import io.ciera.tool.sql.ooaofooa.value.TransientValueReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class TransientValueReferenceSetImpl extends InstanceSet<TransientValueReferenceSet,TransientValueReference> implements TransientValueReferenceSet {

    // attributes
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( TransientValueReference transientvaluereference : this ) transientvaluereference.setVar_ID( ref_Var_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( TransientValueReference transientvaluereference : this ) transientvaluereference.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( TransientValueReference transientvaluereference : this ) valueset.add( transientvaluereference.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R805_references_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( TransientValueReference transientvaluereference : this ) v_varset.add( transientvaluereference.R805_references_V_VAR() );
        return v_varset;
    }


    @Override
    public TransientValueReference nullElement() {
        return TransientValueReferenceImpl.EMPTY_TRANSIENTVALUEREFERENCE;
    }

    @Override
    public TransientValueReferenceSet emptySet() {
      return new TransientValueReferenceSetImpl();
    }

    @Override
    public TransientValueReferenceSet value() {
        return this;
    }

    @Override
    public List<TransientValueReference> elements() {
        return Arrays.asList(toArray(new TransientValueReference[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/TransientValueReferenceSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.value.TransientValueReference;
import io.ciera.tool.sql.ooaofooa.value.TransientValueReferenceSet;
import io.ciera.tool.sql.ooaofooa.value.V_VARSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.V_VARSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class TransientValueReferenceSetImpl extends InstanceSet<TransientValueReferenceSet,TransientValueReference> implements TransientValueReferenceSet {

    public TransientValueReferenceSetImpl() {
    }

    public TransientValueReferenceSetImpl(Comparator<? super TransientValueReference> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( TransientValueReference transientvaluereference : this ) transientvaluereference.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setVar_ID( UniqueId ref_Var_ID ) throws XtumlException {
        for ( TransientValueReference transientvaluereference : this ) transientvaluereference.setVar_ID( ref_Var_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( TransientValueReference transientvaluereference : this ) valueset.add( transientvaluereference.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public V_VARSet R805_references_V_VAR() throws XtumlException {
        V_VARSet v_varset = new V_VARSetImpl();
        for ( TransientValueReference transientvaluereference : this ) v_varset.add( transientvaluereference.R805_references_V_VAR() );
        return v_varset;
    }


    @Override
    public TransientValueReference nullElement() {
        return TransientValueReferenceImpl.EMPTY_TRANSIENTVALUEREFERENCE;
    }

    @Override
    public TransientValueReferenceSet emptySet() {
      return new TransientValueReferenceSetImpl();
    }

    @Override
    public TransientValueReferenceSet emptySet(Comparator<? super TransientValueReference> comp) {
      return new TransientValueReferenceSetImpl(comp);
    }

    @Override
    public TransientValueReferenceSet value() {
        return this;
    }

    @Override
    public List<TransientValueReference> elements() {
        return Arrays.asList(toArray(new TransientValueReference[0]));
    }

}
